==> lint-visualizer-1.0.1.tgz: package/README.md <==
<h1>
  <img align="left" width="40" height="40" src="https://live.staticflickr.com/65535/50304969336_35086b7f64_s.jpg">
	Lint Visualizer
</h1>

> Lint Visualizer provides a smart way to view your project's lint errors & warnings as actionable items

<img src="https://live.staticflickr.com/65535/50305182567_282594780e_h.jpg">

It's time to say BYE BYE to the old-school terminal based output for your lint errors/warnings. With the all new **Lint Visualizer**, you will now have a clear way to visualize your lint errors/warnings and keep track of them as they are being fixed. It comes with a couple of handy features that help you to clearly work on the errors/warnings and easily launch google search for the fix.

> *Currently supports only **Angular** based projects*

## Highlights

- Issues are grouped as Errors/Warnings 
- Resolved issues can be viewed under a separate section
- Easy to copy the results in **JSON** format
- Search for the issue in google by clicking on the issue title

## Installation

Use the package manager **npm** to install lint-visualizer.

```bash
npm install lint-visualizer
```

## Usage

```
$ lint-visualizer -p <Project Name> [options]
```

The results will be available at [http://localhost:8080](http://localhost:8080) once the command is executed successfully 


## Options

| Option | Alias | Description |
| :---: | :---: | :---: |
| `-configuration` | `-c` | Specify the configuration to use |
| `-tslint-config` | `-tc` | The name of the TSLint configuration file |

## Roadmap 🚀

Looking to improve this tool by adding more features going forward as mentioned below:

- Support for the other frameworks and libraries
- Ability to Filter/Sort the results
- Results history with timestamp
- Easy to use light-weight hosted application


## License

![GitHub](https://img.shields.io/github/license/chandrahasstvs/lint-visualizer)

==> lint-visualizer-1.0.3.tgz: package/README.md <==
<h1>
  <img align="left" width="40" height="40" src="https://live.staticflickr.com/65535/50304969336_35086b7f64_s.jpg">
	Lint Visualizer
</h1>

> Lint Visualizer provides a smart way to view your project's lint errors & warnings as actionable items

<img src="https://live.staticflickr.com/65535/50305182567_282594780e_h.jpg">

It's time to say BYE BYE to the old-school terminal based output for your lint errors/warnings. With the all new **Lint Visualizer**, you will now have a clear way to visualize your lint errors/warnings and keep track of them as they are being fixed. It comes with a couple of handy features that help you to clearly work on the errors/warnings and easily launch google search for the fix.

> *Currently supports only **Angular** based projects*


## Highlights

- Issues are grouped as Errors/Warnings 
- Resolved issues can be viewed under a separate section
- Easy to copy the results in **JSON** format
- Search for the issue in google by clicking on the issue title


## Installation

Use the package manager **npm** to install lint-visualizer.

```bash
npm install -D lint-visualizer
```


## Usage

Add the following line to the `package.json` under the scripts section

```
  "scripts": {
    
    ...

    "lint-visualizer": "lint-visualizer -p <Project Name> [options]"
  }
```

Now run the following command to see the **Lint Visualizer** in action

```
$ npm run lint-visualizer
```

The results will be available at [http://localhost:8080](http://localhost:8080) once the command is executed successfully 


## Options

| Option | Alias | Description |
| :---: | :---: | :---: |
| `-configuration` | `-c` | Specify the configuration to use |
| `-tslint-config` | `-tc` | The name of the TSLint configuration file |


## Roadmap 🚀

Looking to improve this tool by adding more features going forward as mentioned below:

- Support for the other frameworks and libraries
- Ability to Filter/Sort the results
- Results history with timestamp
- Easy to use light-weight hosted application


## License

![GitHub](https://img.shields.io/github/license/chandrahasstvs/lint-visualizer)
